VerifoneApi class

Constructors

VerifoneApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connectToDevice(dynamic device) Future<void>
discoverDevices() Future<List>
enableBluetooth() Future<void>
realizarPago(double cantidad) Future<void>